USE IDENTIFIER(:database);

truncate table dim_stores;
-- Insert store data for retail chain
INSERT INTO dim_stores (
    store_id, store_name, store_address, store_city, store_state, store_zipcode, 
    store_country, store_phone, store_email, store_manager_id, opening_date, 
    store_area_sqft, is_open_24_hours, latitude, longitude, region_id, store_details_text
) VALUES
-- New York Area Stores
('001', 'Downtown', '123 Main St', 'New York', 'NY', '10001', 'USA', '(212) 555-1234', 'downtown@com', 'mgr_001', '2015-05-20', 5000.0, true, 40.7128, -74.006, '1', 'Downtown store #001 located at 123 Main St, New York, NY 10001. Large 5000.0 sq ft store open 24 hours serving the New York area. Contact: (212) 555-1234, downtown@com. Opened May 2015, managed by mgr_001. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('002', 'Uptown', '456 Broadway', 'New York', 'NY', '10002', 'USA', '(212) 555-5678', 'uptown@com', 'mgr_002', '2018-07-15', 3000.0, false, 40.7138, -74.007, '1', 'Uptown store #002 located at 456 Broadway, New York, NY 10002. Mid-size 3000.0 sq ft store with regular business hours serving the New York area. Contact: (212) 555-5678, uptown@com. Opened July 2018, managed by mgr_002. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('003', 'Manhattan Mini', '789 5th Avenue', 'New York', 'NY', '10003', 'USA', '(212) 555-9012', 'manhattanmini@com', 'mgr_003', '2016-03-10', 2500.0, true, 40.7589, -73.9851, '1', 'Manhattan Mini store #003 located at 789 5th Avenue, New York, NY 10003. Compact 2500.0 sq ft store open 24 hours serving the New York area. Contact: (212) 555-9012, manhattanmini@com. Opened March 2016, managed by mgr_003. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('004', 'Bronx', '321 Fordham Road', 'New York', 'NY', '10458', 'USA', '(718) 555-3456', 'bronx@com', 'mgr_004', '2017-08-22', 4500.0, false, 40.8614, -73.8827, '1', 'Bronx store #004 located at 321 Fordham Road, New York, NY 10458. Large 4500.0 sq ft store with regular business hours serving the New York area. Contact: (718) 555-3456, bronx@com. Opened August 2017, managed by mgr_004. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('005', 'Queens Corner', '567 Queens Blvd', 'New York', 'NY', '11375', 'USA', '(718) 555-7890', 'queens@com', 'mgr_005', '2019-01-15', 3800.0, true, 40.7282, -73.8618, '1', 'Queens Corner store #005 located at 567 Queens Blvd, New York, NY 11375. Spacious 3800.0 sq ft store open 24 hours serving the New York area. Contact: (718) 555-7890, queens@com. Opened January 2019, managed by mgr_005. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('006', 'Brooklyn Heights', '123 Montague St', 'New York', 'NY', '11201', 'USA', '(718) 555-4321', 'brooklyn@com', 'mgr_006', '2020-03-01', 2800.0, false, 40.6935, -73.9916, '1', 'Brooklyn Heights store #006 located at 123 Montague St, New York, NY 11201. Compact 2800.0 sq ft store with regular business hours serving the New York area. Contact: (718) 555-4321, brooklyn@com. Opened March 2020, managed by mgr_006. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('007', 'Staten Island', '789 Hylan Blvd', 'New York', 'NY', '10305', 'USA', '(718) 555-8765', 'statenisland@com', 'mgr_007', '2018-06-15', 4200.0, true, 40.6065, -74.0752, '1', 'Staten Island store #007 located at 789 Hylan Blvd, New York, NY 10305. Large 4200.0 sq ft store open 24 hours serving the New York area. Contact: (718) 555-8765, statenisland@com. Opened June 2018, managed by mgr_007. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('008', 'Harlem', '456 Malcolm X Blvd', 'New York', 'NY', '10027', 'USA', '(212) 555-9876', 'harlem@com', 'mgr_008', '2017-11-30', 3500.0, false, 40.8116, -73.9465, '1', 'Harlem store #008 located at 456 Malcolm X Blvd, New York, NY 10027. Spacious 3500.0 sq ft store with regular business hours serving the New York area. Contact: (212) 555-9876, harlem@com. Opened November 2017, managed by mgr_008. Convenient location in New York, NY with excellent customer service and wide product selection.'),
('009', 'Lower East Side', '234 Delancey St', 'New York', 'NY', '10002', 'USA', '(212) 555-3456', 'les@com', 'mgr_009', '2019-08-22', 2600.0, true, 40.7168, -73.9861, '1', 'Lower East Side store #009 located at 234 Delancey St, New York, NY 10002. Compact 2600.0 sq ft store open 24 hours serving the New York area. Contact: (212) 555-3456, les@com. Opened August 2019, managed by mgr_009. Convenient location in New York, NY with excellent customer service and wide product selection.'),

-- Boston Area Stores
('010', 'Back Bay', '100 Boylston St', 'Boston', 'MA', '02116', 'USA', '(617) 555-1234', 'backbay@com', 'mgr_010', '2018-03-15', 3200.0, false, 42.3518, -71.0711, '1', 'Back Bay store #010 located at 100 Boylston St, Boston, MA 02116. Mid-size 3200.0 sq ft store with regular business hours serving the Boston area. Contact: (617) 555-1234, backbay@com. Opened March 2018, managed by mgr_010. Convenient location in Boston, MA with excellent customer service and wide product selection.'),
('011', 'Beacon Hill', '89 Charles St', 'Boston', 'MA', '02114', 'USA', '(617) 555-2345', 'beaconhill@com', 'mgr_011', '2019-05-01', 2800.0, false, 42.356, -71.0705, '1', 'Beacon Hill store #011 located at 89 Charles St, Boston, MA 02114. Compact 2800.0 sq ft store with regular business hours serving the Boston area. Contact: (617) 555-2345, beaconhill@com. Opened May 2019, managed by mgr_011. Convenient location in Boston, MA with excellent customer service and wide product selection.'),
('012', 'South End', '540 Tremont St', 'Boston', 'MA', '02118', 'USA', '(617) 555-3456', 'southend@com', 'mgr_012', '2017-09-12', 3500.0, true, 42.3433, -71.0726, '1', 'South End store #012 located at 540 Tremont St, Boston, MA 02118. Spacious 3500.0 sq ft store open 24 hours serving the Boston area. Contact: (617) 555-3456, southend@com. Opened September 2017, managed by mgr_012. Convenient location in Boston, MA with excellent customer service and wide product selection.'),
('013', 'Fenway', '123 Brookline Ave', 'Boston', 'MA', '02215', 'USA', '(617) 555-4567', 'fenway@com', 'mgr_013', '2020-01-15', 4000.0, false, 42.3467, -71.0972, '1', 'Fenway store #013 located at 123 Brookline Ave, Boston, MA 02215. Large 4000.0 sq ft store with regular business hours serving the Boston area. Contact: (617) 555-4567, fenway@com. Opened January 2020, managed by mgr_013. Convenient location in Boston, MA with excellent customer service and wide product selection.'),
('014', 'Cambridge', '750 Memorial Dr', 'Boston', 'MA', '02139', 'USA', '(617) 555-5678', 'cambridge@com', 'mgr_014', '2018-11-30', 3800.0, true, 42.3576, -71.1009, '1', 'Cambridge store #014 located at 750 Memorial Dr, Boston, MA 02139. Spacious 3800.0 sq ft store open 24 hours serving the Boston area. Contact: (617) 555-5678, cambridge@com. Opened November 2018, managed by mgr_014. Convenient location in Boston, MA with excellent customer service and wide product selection.'),

-- Philadelphia Area Stores
('015', 'Center City', '1200 Market St', 'Philadelphia', 'PA', '19107', 'USA', '(215) 555-1234', 'centercity@com', 'mgr_015', '2019-04-01', 4500.0, true, 39.9526, -75.1652, '1', 'Center City store #015 located at 1200 Market St, Philadelphia, PA 19107. Large 4500.0 sq ft store open 24 hours serving the Philadelphia area. Contact: (215) 555-1234, centercity@com. Opened April 2019, managed by mgr_015. Convenient location in Philadelphia, PA with excellent customer service and wide product selection.'),
('016', 'South Philly', '1001 S 9th St', 'Philadelphia', 'PA', '19147', 'USA', '(215) 555-2345', 'southphilly@com', 'mgr_016', '2017-07-15', 3300.0, false, 39.9375, -75.1571, '1', 'South Philly store #016 located at 1001 S 9th St, Philadelphia, PA 19147. Mid-size 3300.0 sq ft store with regular business hours serving the Philadelphia area. Contact: (215) 555-2345, southphilly@com. Opened July 2017, managed by mgr_016. Convenient location in Philadelphia, PA with excellent customer service and wide product selection.'),
('017', 'University City', '3401 Walnut St', 'Philadelphia', 'PA', '19104', 'USA', '(215) 555-3456', 'univcity@com', 'mgr_017', '2020-02-28', 2900.0, true, 39.9522, -75.1932, '1', 'University City store #017 located at 3401 Walnut St, Philadelphia, PA 19104. Compact 2900.0 sq ft store open 24 hours serving the Philadelphia area. Contact: (215) 555-3456, univcity@com. Opened February 2020, managed by mgr_017. Convenient location in Philadelphia, PA with excellent customer service and wide product selection.'),
('018', 'Northern Liberties', '180 W Girard Ave', 'Philadelphia', 'PA', '19123', 'USA', '(215) 555-4567', 'noliberties@com', 'mgr_018', '2018-09-01', 3700.0, false, 39.9697, -75.1398, '1', 'Northern Liberties store #018 located at 180 W Girard Ave, Philadelphia, PA 19123. Spacious 3700.0 sq ft store with regular business hours serving the Philadelphia area. Contact: (215) 555-4567, noliberties@com. Opened September 2018, managed by mgr_018. Convenient location in Philadelphia, PA with excellent customer service and wide product selection.'),
('019', 'Rittenhouse Square', '1800 Walnut St', 'Philadelphia', 'PA', '19103', 'USA', '(215) 555-5678', 'rittenhouse@com', 'mgr_019', '2019-11-15', 4100.0, true, 39.9496, -75.1709, '1', 'Rittenhouse Square store #019 located at 1800 Walnut St, Philadelphia, PA 19103. Large 4100.0 sq ft store open 24 hours serving the Philadelphia area. Contact: (215) 555-5678, rittenhouse@com. Opened November 2019, managed by mgr_019. Convenient location in Philadelphia, PA with excellent customer service and wide product selection.'),

-- Washington DC Area Stores
('020', 'Georgetown', '1200 Wisconsin Ave NW', 'Washington D.C.', 'DC', '20007', 'USA', '(202) 555-1234', 'georgetown@com', 'mgr_020', '2018-04-15', 3800.0, false, 38.9055, -77.067, '2', 'Georgetown store #020 located at 1200 Wisconsin Ave NW, Washington D.C., DC 20007. Spacious 3800.0 Sq Ft store with regular business hours serving the Washington D.C. area. Contact: (202) 555-1234, georgetown@com. Opened April 2018, managed by mgr_020. Convenient location in Washington D.C., DC with excellent customer service and wide product selection.'),
('022', 'Capitol Hill', '400 East Capitol St NE', 'Washington D.C.', 'DC', '20003', 'USA', '(202) 555-3456', 'capitolhill@com', 'mgr_022', '2017-08-30', 2900.0, false, 38.8898, -77.0001, '2', 'Capitol Hill store #022 located at 400 East Capitol St NE, Washington D.C., DC 20003. Compact 2900.0 Sq Ft store with regular business hours serving the Washington D.C. area. Contact: (202) 555-3456, capitolhill@com. Opened August 2017, managed by mgr_022. Convenient location in Washington D.C., DC with excellent customer service and wide product selection.'),
('023', 'Adams Morgan', '1700 Columbia Rd NW', 'Washington D.C.', 'DC', '20009', 'USA', '(202) 555-4567', 'adamsmorgan@com', 'mgr_023', '2020-03-15', 3500.0, true, 38.9222, -77.0421, '2', 'Adams Morgan store #023 located at 1700 Columbia Rd NW, Washington D.C., DC 20009. Spacious 3500.0 Sq Ft store with open 24 hours serving the Washington D.C. area. Contact: (202) 555-4567, adamsmorgan@com. Opened March 2020, managed by mgr_023. Convenient location in Washington D.C., DC with excellent customer service and wide product selection.'),
('024', 'U Street', '1400 U St NW', 'Washington D.C.', 'DC', '20009', 'USA', '(202) 555-5678', 'ustreet@com', 'mgr_024', '2019-09-01', 3100.0, false, 38.9169, -77.0312, '2', 'U Street store #024 located at 1400 U St NW, Washington D.C., DC 20009. Mid-Size 3100.0 Sq Ft store with regular business hours serving the Washington D.C. area. Contact: (202) 555-5678, ustreet@com. Opened September 2019, managed by mgr_024. Convenient location in Washington D.C., DC with excellent customer service and wide product selection.'),

-- Baltimore Area Stores
('025', 'Inner Harbor', '600 E Pratt St', 'Baltimore', 'MD', '21202', 'USA', '(410) 555-1234', 'innerharbor@com', 'mgr_025', '2018-07-01', 4200.0, true, 39.2866, -76.6089, '2', 'Inner Harbor store #025 located at 600 E Pratt St, Baltimore, MD 21202. Spacious 4200.0 Sq Ft store with open 24 hours serving the Baltimore area. Contact: (410) 555-1234, innerharbor@com. Opened July 2018, managed by mgr_025. Convenient location in Baltimore, MD with excellent customer service and wide product selection.'),
('026', 'Fells Point', '1700 Thames St', 'Baltimore', 'MD', '21231', 'USA', '(410) 555-2345', 'fellspoint@com', 'mgr_026', '2019-04-15', 3300.0, false, 39.2819, -76.5943, '2', 'Fells Point store #026 located at 1700 Thames St, Baltimore, MD 21231. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Baltimore area. Contact: (410) 555-2345, fellspoint@com. Opened April 2019, managed by mgr_026. Convenient location in Baltimore, MD with excellent customer service and wide product selection.'),
('027', 'Canton', '2800 O''Donnell St', 'Baltimore', 'MD', '21224', 'USA', '(410) 555-3456', 'canton@com', 'mgr_027', '2017-11-30', 3600.0, true, 39.2792, -76.5762, '2', 'Canton store #027 located at 2800 O''Donnell St, Baltimore, MD 21224. Spacious 3600.0 sq ft store open 24 hours serving the Baltimore area. Contact: (410) 555-3456, canton@com. Opened November 2017, managed by mgr_027. Convenient location in Baltimore, MD with excellent customer service and wide product selection.'),
('028', 'Federal Hill', '1000 Light St', 'Baltimore', 'MD', '21230', 'USA', '(410) 555-4567', 'fedhill@com', 'mgr_028', '2020-01-15', 2800.0, false, 39.2775, -76.6134, '2', 'Federal Hill store #028 located at 1000 Light St, Baltimore, MD 21230. Compact 2800.0 Sq Ft store with regular business hours serving the Baltimore area. Contact: (410) 555-4567, fedhill@com. Opened January 2020, managed by mgr_028. Convenient location in Baltimore, MD with excellent customer service and wide product selection.'),
('029', 'Mount Vernon', '600 N Charles St', 'Baltimore', 'MD', '21201', 'USA', '(410) 555-5678', 'mtvernon@com', 'mgr_029', '2019-08-01', 3400.0, true, 39.2967, -76.6156, '2', 'Mount Vernon store #029 located at 600 N Charles St, Baltimore, MD 21201. Mid-Size 3400.0 Sq Ft store with open 24 hours serving the Baltimore area. Contact: (410) 555-5678, mtvernon@com. Opened August 2019, managed by mgr_029. Convenient location in Baltimore, MD with excellent customer service and wide product selection.'),

-- Richmond Area Stores
('030', 'Carytown', '3500 W Cary St', 'Richmond', 'VA', '23221', 'USA', '(804) 555-1234', 'carytown@com', 'mgr_030', '2018-05-15', 3700.0, false, 37.5552, -77.4856, '2', 'Carytown store #030 located at 3500 W Cary St, Richmond, VA 23221. Spacious 3700.0 Sq Ft store with regular business hours serving the Richmond area. Contact: (804) 555-1234, carytown@com. Opened May 2018, managed by mgr_030. Convenient location in Richmond, VA with excellent customer service and wide product selection.'),
('031', 'Shockoe Bottom', '1800 E Main St', 'Richmond', 'VA', '23223', 'USA', '(804) 555-2345', 'shockoe@com', 'mgr_031', '2019-03-01', 3200.0, true, 37.5315, -77.4267, '2', 'Shockoe Bottom store #031 located at 1800 E Main St, Richmond, VA 23223. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Richmond area. Contact: (804) 555-2345, shockoe@com. Opened March 2019, managed by mgr_031. Convenient location in Richmond, VA with excellent customer service and wide product selection.'),
('032', 'Fan District', '2200 W Main St', 'Richmond', 'VA', '23220', 'USA', '(804) 555-3456', 'fandistrict@com', 'mgr_032', '2017-10-15', 2900.0, false, 37.5539, -77.4673, '2', 'Fan District store #032 located at 2200 W Main St, Richmond, VA 23220. Compact 2900.0 Sq Ft store with regular business hours serving the Richmond area. Contact: (804) 555-3456, fandistrict@com. Opened October 2017, managed by mgr_032. Convenient location in Richmond, VA with excellent customer service and wide product selection.'),
('033', 'Scott''s Addition', '3000 W Broad St', 'Richmond', 'VA', '23230', 'USA', '(804) 555-4567', 'scottsadd@com', 'mgr_033', '2020-02-01', 3800.0, true, 37.5668, -77.4747, '2', 'Scott''s Addition store #033 located at 3000 W Broad St, Richmond, VA 23230. Spacious 3800.0 sq ft store open 24 hours serving the Richmond area. Contact: (804) 555-4567, scottsadd@com. Opened February 2020, managed by mgr_033. Convenient location in Richmond, VA with excellent customer service and wide product selection.'),
('034', 'Church Hill', '2500 E Broad St', 'Richmond', 'VA', '23223', 'USA', '(804) 555-5678', 'churchhill@com', 'mgr_034', '2019-07-15', 3100.0, false, 37.5338, -77.4178, '2', 'Church Hill store #034 located at 2500 E Broad St, Richmond, VA 23223. Mid-Size 3100.0 Sq Ft store with regular business hours serving the Richmond area. Contact: (804) 555-5678, churchhill@com. Opened July 2019, managed by mgr_034. Convenient location in Richmond, VA with excellent customer service and wide product selection.'),

-- Atlanta Area Stores
('036', 'Buckhead', '3255 Peachtree Rd', 'Atlanta', 'GA', '30305', 'USA', '(404) 555-1234', 'buckhead@com', 'mgr_036', '2017-05-15', 4200.0, false, 33.8406, -84.3795, '3', 'Buckhead store #036 located at 3255 Peachtree Rd, Atlanta, GA 30305. Spacious 4200.0 Sq Ft store with regular business hours serving the Atlanta area. Contact: (404) 555-1234, buckhead@com. Opened May 2017, managed by mgr_036. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('037', 'Midtown Atlanta', '950 W Peachtree St', 'Atlanta', 'GA', '30309', 'USA', '(404) 555-2345', 'midtown@com', 'mgr_037', '2019-03-01', 3500.0, true, 33.7815, -84.3885, '3', 'Midtown Atlanta store #037 located at 950 W Peachtree St, Atlanta, GA 30309. Spacious 3500.0 Sq Ft store with open 24 hours serving the Atlanta area. Contact: (404) 555-2345, midtown@com. Opened March 2019, managed by mgr_037. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('046', 'Midtown West', '950 West Peachtree St NW', 'Atlanta', 'GA', '30309', 'USA', '(404) 555-1234', 'midtownatl@com', 'mgr_046', '2018-04-15', 3400.0, true, 33.7815, -84.3857, '3', 'Midtown West store #046 located at 950 West Peachtree St NW, Atlanta, GA 30309. Mid-Size 3400.0 Sq Ft store with open 24 hours serving the Atlanta area. Contact: (404) 555-1234, midtownatl@com. Opened April 2018, managed by mgr_046. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('047', 'Buckhead North', '3035 Peachtree Rd NE', 'Atlanta', 'GA', '30305', 'USA', '(404) 555-2345', 'buckheadnorth@com', 'mgr_047', '2017-12-10', 3800.0, false, 33.8399, -84.3801, '3', 'Buckhead North store #047 located at 3035 Peachtree Rd NE, Atlanta, GA 30305. Spacious 3800.0 Sq Ft store with regular business hours serving the Atlanta area. Contact: (404) 555-2345, buckheadnorth@com. Opened December 2017, managed by mgr_047. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('048', 'Virginia Highland', '1001 Virginia Ave NE', 'Atlanta', 'GA', '30306', 'USA', '(404) 555-3456', 'vahighland@com', 'mgr_048', '2019-02-20', 2700.0, false, 33.7817, -84.3571, '3', 'Virginia Highland store #048 located at 1001 Virginia Ave NE, Atlanta, GA 30306. Compact 2700.0 Sq Ft store with regular business hours serving the Atlanta area. Contact: (404) 555-3456, vahighland@com. Opened February 2019, managed by mgr_048. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('049', 'Little Five Points', '421 Moreland Ave NE', 'Atlanta', 'GA', '30307', 'USA', '(404) 555-4567', 'l5p@com', 'mgr_049', '2018-09-05', 2500.0, true, 33.7618, -84.349, '3', 'Little Five Points store #049 located at 421 Moreland Ave NE, Atlanta, GA 30307. Compact 2500.0 Sq Ft store with open 24 hours serving the Atlanta area. Contact: (404) 555-4567, l5p@com. Opened September 2018, managed by mgr_049. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),
('050', 'West Midtown', '1100 Howell Mill Rd NW', 'Atlanta', 'GA', '30318', 'USA', '(404) 555-5678', 'westmidtown@com', 'mgr_050', '2020-01-15', 3300.0, false, 33.7861, -84.4113, '3', 'West Midtown store #050 located at 1100 Howell Mill Rd NW, Atlanta, GA 30318. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Atlanta area. Contact: (404) 555-5678, westmidtown@com. Opened January 2020, managed by mgr_050. Convenient location in Atlanta, GA with excellent customer service and wide product selection.'),

-- Miami Area Stores
('038', 'South Beach', '1020 Ocean Dr', 'Miami', 'FL', '33139', 'USA', '(305) 555-1234', 'southbeach@com', 'mgr_038', '2018-12-01', 2900.0, true, 25.7825, -80.1324, '3', 'South Beach store #038 located at 1020 Ocean Dr, Miami, FL 33139. Compact 2900.0 Sq Ft store with open 24 hours serving the Miami area. Contact: (305) 555-1234, southbeach@com. Opened December 2018, managed by mgr_038. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('039', 'Brickell', '901 S Miami Ave', 'Miami', 'FL', '33130', 'USA', '(305) 555-2345', 'brickell@com', 'mgr_039', '2017-09-15', 3800.0, false, 25.7657, -80.1937, '3', 'Brickell store #039 located at 901 S Miami Ave, Miami, FL 33130. Spacious 3800.0 Sq Ft store with regular business hours serving the Miami area. Contact: (305) 555-2345, brickell@com. Opened September 2017, managed by mgr_039. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('041', 'Little Havana', '1200 SW 8th St', 'Miami', 'FL', '33135', 'USA', '(305) 555-3456', 'littlehavana@com', 'mgr_041', '2019-03-15', 3200.0, true, 25.7655, -80.2179, '3', 'Little Havana store #041 located at 1200 SW 8th St, Miami, FL 33135. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Miami area. Contact: (305) 555-3456, littlehavana@com. Opened March 2019, managed by mgr_041. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('042', 'Wynwood', '250 NW 24th St', 'Miami', 'FL', '33127', 'USA', '(305) 555-4567', 'wynwood@com', 'mgr_042', '2020-01-10', 2900.0, false, 25.7994, -80.1989, '3', 'Wynwood store #042 located at 250 NW 24th St, Miami, FL 33127. Compact 2900.0 Sq Ft store with regular business hours serving the Miami area. Contact: (305) 555-4567, wynwood@com. Opened January 2020, managed by mgr_042. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('043', 'Coral Gables', '2200 Ponce de Leon Blvd', 'Miami', 'FL', '33134', 'USA', '(305) 555-5678', 'coralgables@com', 'mgr_043', '2017-11-20', 3500.0, false, 25.7501, -80.259, '3', 'Coral Gables store #043 located at 2200 Ponce de Leon Blvd, Miami, FL 33134. Spacious 3500.0 Sq Ft store with regular business hours serving the Miami area. Contact: (305) 555-5678, coralgables@com. Opened November 2017, managed by mgr_043. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('044', 'Coconut Grove', '3330 Grand Ave', 'Miami', 'FL', '33133', 'USA', '(305) 555-6789', 'coconutgrove@com', 'mgr_044', '2018-08-05', 2600.0, true, 25.7269, -80.2425, '3', 'Coconut Grove store #044 located at 3330 Grand Ave, Miami, FL 33133. Compact 2600.0 Sq Ft store with open 24 hours serving the Miami area. Contact: (305) 555-6789, coconutgrove@com. Opened August 2018, managed by mgr_044. Convenient location in Miami, FL with excellent customer service and wide product selection.'),
('045', 'Downtown Miami', '100 SE 2nd St', 'Miami', 'FL', '33131', 'USA', '(305) 555-7890', 'downtown@com', 'mgr_045', '2019-06-01', 3100.0, true, 25.7743, -80.1937, '3', 'Downtown Miami store #045 located at 100 SE 2nd St, Miami, FL 33131. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Miami area. Contact: (305) 555-7890, downtown@com. Opened June 2019, managed by mgr_045. Convenient location in Miami, FL with excellent customer service and wide product selection.'),

-- Charlotte Area Stores
('040', 'Dilworth', '1235 East Blvd', 'Charlotte', 'NC', '28203', 'USA', '(704) 555-1234', 'dilworth@com', 'mgr_040', '2019-04-01', 3300.0, false, 35.2089, -80.8486, '3', 'Dilworth store #040 located at 1235 East Blvd, Charlotte, NC 28203. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Charlotte area. Contact: (704) 555-1234, dilworth@com. Opened April 2019, managed by mgr_040. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),
('051', 'South End', '2100 South Blvd', 'Charlotte', 'NC', '28203', 'USA', '(704) 555-1234', 'southend@com', 'mgr_051', '2019-03-15', 3500.0, true, 35.2098, -80.8577, '3', 'South End store #051 located at 2100 South Blvd, Charlotte, NC 28203. Spacious 3500.0 Sq Ft store with open 24 hours serving the Charlotte area. Contact: (704) 555-1234, southend@com. Opened March 2019, managed by mgr_051. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),
('052', 'NoDa', '3201 N Davidson St', 'Charlotte', 'NC', '28205', 'USA', '(704) 555-2345', 'noda@com', 'mgr_052', '2018-07-01', 2800.0, false, 35.2424, -80.8024, '3', 'NoDa store #052 located at 3201 N Davidson St, Charlotte, NC 28205. Compact 2800.0 Sq Ft store with regular business hours serving the Charlotte area. Contact: (704) 555-2345, noda@com. Opened July 2018, managed by mgr_052. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),
('053', 'Plaza Midwood', '1600 Central Ave', 'Charlotte', 'NC', '28205', 'USA', '(704) 555-3456', 'plazamidwood@com', 'mgr_053', '2017-11-15', 3200.0, true, 35.2206, -80.8099, '3', 'Plaza Midwood store #053 located at 1600 Central Ave, Charlotte, NC 28205. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Charlotte area. Contact: (704) 555-3456, plazamidwood@com. Opened November 2017, managed by mgr_053. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),
('054', 'Uptown', '300 S Tryon St', 'Charlotte', 'NC', '28202', 'USA', '(704) 555-4567', 'uptown@com', 'mgr_054', '2020-02-01', 2900.0, true, 35.2271, -80.8431, '3', 'Uptown store #054 located at 300 S Tryon St, Charlotte, NC 28202. Compact 2900.0 Sq Ft store with open 24 hours serving the Charlotte area. Contact: (704) 555-4567, uptown@com. Opened February 2020, managed by mgr_054. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),
('055', 'Myers Park', '1024 Providence Rd', 'Charlotte', 'NC', '28207', 'USA', '(704) 555-5678', 'myerspark@com', 'mgr_055', '2019-08-15', 3800.0, false, 35.2033, -80.8241, '3', 'Myers Park store #055 located at 1024 Providence Rd, Charlotte, NC 28207. Spacious 3800.0 Sq Ft store with regular business hours serving the Charlotte area. Contact: (704) 555-5678, myerspark@com. Opened August 2019, managed by mgr_055. Convenient location in Charlotte, NC with excellent customer service and wide product selection.'),

-- Chicago Area Stores
('056', 'Loop', '200 N Michigan Ave', 'Chicago', 'IL', '60601', 'USA', '(312) 555-1234', 'loop@com', 'mgr_056', '2018-05-01', 4200.0, true, 41.8857, -87.6244, '4', 'Loop store #056 located at 200 N Michigan Ave, Chicago, IL 60601. Spacious 4200.0 Sq Ft store with open 24 hours serving the Chicago area. Contact: (312) 555-1234, loop@com. Opened May 2018, managed by mgr_056. Convenient location in Chicago, IL with excellent customer service and wide product selection.'),
('057', 'Wicker Park', '1600 N Milwaukee Ave', 'Chicago', 'IL', '60647', 'USA', '(312) 555-2345', 'wickerpark@com', 'mgr_057', '2019-06-15', 3500.0, false, 41.9103, -87.6731, '4', 'Wicker Park store #057 located at 1600 N Milwaukee Ave, Chicago, IL 60647. Spacious 3500.0 Sq Ft store with regular business hours serving the Chicago area. Contact: (312) 555-2345, wickerpark@com. Opened June 2019, managed by mgr_057. Convenient location in Chicago, IL with excellent customer service and wide product selection.'),
('058', 'Lincoln Park', '2400 N Clark St', 'Chicago', 'IL', '60614', 'USA', '(312) 555-3456', 'lincolnpark@com', 'mgr_058', '2017-09-01', 3800.0, true, 41.9256, -87.6412, '4', 'Lincoln Park store #058 located at 2400 N Clark St, Chicago, IL 60614. Spacious 3800.0 Sq Ft store with open 24 hours serving the Chicago area. Contact: (312) 555-3456, lincolnpark@com. Opened September 2017, managed by mgr_058. Convenient location in Chicago, IL with excellent customer service and wide product selection.'),
('059', 'Logan Square', '2800 N Milwaukee Ave', 'Chicago', 'IL', '60618', 'USA', '(312) 555-4567', 'logan@com', 'mgr_059', '2020-03-01', 3100.0, false, 41.9302, -87.7024, '4', 'Logan Square store #059 located at 2800 N Milwaukee Ave, Chicago, IL 60618. Mid-Size 3100.0 Sq Ft store with regular business hours serving the Chicago area. Contact: (312) 555-4567, logan@com. Opened March 2020, managed by mgr_059. Convenient location in Chicago, IL with excellent customer service and wide product selection.'),
('060', 'River North', '500 N State St', 'Chicago', 'IL', '60654', 'USA', '(312) 555-5678', 'rivernorth@com', 'mgr_060', '2019-04-15', 4000.0, true, 41.8907, -87.6278, '4', 'River North store #060 located at 500 N State St, Chicago, IL 60654. Spacious 4000.0 Sq Ft store with open 24 hours serving the Chicago area. Contact: (312) 555-5678, rivernorth@com. Opened April 2019, managed by mgr_060. Convenient location in Chicago, IL with excellent customer service and wide product selection.'),

-- Detroit Area Stores
('061', 'Midtown Detroit', '4400 Woodward Ave', 'Detroit', 'MI', '48201', 'USA', '(313) 555-1234', 'midtown@com', 'mgr_061', '2018-08-01', 3600.0, true, 42.3516, -83.0602, '4', 'Midtown Detroit store #061 located at 4400 Woodward Ave, Detroit, MI 48201. Spacious 3600.0 Sq Ft store with open 24 hours serving the Detroit area. Contact: (313) 555-1234, midtown@com. Opened August 2018, managed by mgr_061. Convenient location in Detroit, MI with excellent customer service and wide product selection.'),
('062', 'Corktown', '1700 Michigan Ave', 'Detroit', 'MI', '48216', 'USA', '(313) 555-2345', 'corktown@com', 'mgr_062', '2019-05-15', 3200.0, false, 42.3316, -83.0768, '4', 'Corktown store #062 located at 1700 Michigan Ave, Detroit, MI 48216. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Detroit area. Contact: (313) 555-2345, corktown@com. Opened May 2019, managed by mgr_062. Convenient location in Detroit, MI with excellent customer service and wide product selection.'),
('063', 'Eastern Market', '2934 Russell St', 'Detroit', 'MI', '48207', 'USA', '(313) 555-3456', 'easternmarket@com', 'mgr_063', '2017-12-01', 4100.0, true, 42.3476, -83.0419, '4', 'Eastern Market store #063 located at 2934 Russell St, Detroit, MI 48207. Spacious 4100.0 Sq Ft store with open 24 hours serving the Detroit area. Contact: (313) 555-3456, easternmarket@com. Opened December 2017, managed by mgr_063. Convenient location in Detroit, MI with excellent customer service and wide product selection.'),

-- Indianapolis Area Stores
('066', 'Mass Ave', '400 Massachusetts Ave', 'Indianapolis', 'IN', '46204', 'USA', '(317) 555-1234', 'massave@com', 'mgr_066', '2018-06-15', 3300.0, true, 39.7703, -86.1519, '4', 'Mass Ave store #066 located at 400 Massachusetts Ave, Indianapolis, IN 46204. Mid-Size 3300.0 Sq Ft store with open 24 hours serving the Indianapolis area. Contact: (317) 555-1234, massave@com. Opened June 2018, managed by mgr_066. Convenient location in Indianapolis, IN with excellent customer service and wide product selection.'),
('067', 'Broad Ripple', '6280 N College Ave', 'Indianapolis', 'IN', '46220', 'USA', '(317) 555-2345', 'broadripple@com', 'mgr_067', '2019-09-01', 2900.0, false, 39.8703, -86.1445, '4', 'Broad Ripple store #067 located at 6280 N College Ave, Indianapolis, IN 46220. Compact 2900.0 Sq Ft store with regular business hours serving the Indianapolis area. Contact: (317) 555-2345, broadripple@com. Opened September 2019, managed by mgr_067. Convenient location in Indianapolis, IN with excellent customer service and wide product selection.'),
('068', 'Fountain Square', '1043 Virginia Ave', 'Indianapolis', 'IN', '46203', 'USA', '(317) 555-3456', 'fountainsq@com', 'mgr_068', '2017-10-15', 3100.0, true, 39.7536, -86.142, '4', 'Fountain Square store #068 located at 1043 Virginia Ave, Indianapolis, IN 46203. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Indianapolis area. Contact: (317) 555-3456, fountainsq@com. Opened October 2017, managed by mgr_068. Convenient location in Indianapolis, IN with excellent customer service and wide product selection.'),
('069', 'Downtown Indy', '50 S Meridian St', 'Indianapolis', 'IN', '46204', 'USA', '(317) 555-4567', 'downtownindy@com', 'mgr_069', '2020-01-01', 3600.0, true, 39.7668, -86.1577, '4', 'Downtown Indy store #069 located at 50 S Meridian St, Indianapolis, IN 46204. Spacious 3600.0 Sq Ft store with open 24 hours serving the Indianapolis area. Contact: (317) 555-4567, downtownindy@com. Opened January 2020, managed by mgr_069. Convenient location in Indianapolis, IN with excellent customer service and wide product selection.'),

-- Kansas City Area Stores
('134', 'Plaza', '4750 Broadway', 'Kansas City', 'MO', '64112', 'USA', '(816) 555-1234', 'plaza@com', 'mgr_134', '2018-05-15', 4100.0, true, 39.042, -94.5906, '4', 'Plaza store #134 located at 4750 Broadway, Kansas City, MO 64112. Spacious 4100.0 Sq Ft store with open 24 hours serving the Kansas City area. Contact: (816) 555-1234, plaza@com. Opened May 2018, managed by mgr_134. Convenient location in Kansas City, MO with excellent customer service and wide product selection.'),
('135', 'Westport', '4050 Pennsylvania Ave', 'Kansas City', 'MO', '64111', 'USA', '(816) 555-2345', 'westport@com', 'mgr_135', '2019-09-01', 3200.0, false, 39.0505, -94.5906, '4', 'Westport store #135 located at 4050 Pennsylvania Ave, Kansas City, MO 64111. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Kansas City area. Contact: (816) 555-2345, westport@com. Opened September 2019, managed by mgr_135. Convenient location in Kansas City, MO with excellent customer service and wide product selection.'),
('136', 'Crossroads', '2020 Baltimore Ave', 'Kansas City', 'MO', '64108', 'USA', '(816) 555-3456', 'crossroads@com', 'mgr_136', '2017-10-15', 2900.0, true, 39.0914, -94.5836, '4', 'Crossroads store #136 located at 2020 Baltimore Ave, Kansas City, MO 64108. Compact 2900.0 Sq Ft store with open 24 hours serving the Kansas City area. Contact: (816) 555-3456, crossroads@com. Opened October 2017, managed by mgr_136. Convenient location in Kansas City, MO with excellent customer service and wide product selection.'),
('137', 'River Market', '411 Delaware St', 'Kansas City', 'MO', '64105', 'USA', '(816) 555-4567', 'rivermarket@com', 'mgr_137', '2020-04-01', 3600.0, false, 39.1089, -94.5829, '4', 'River Market store #137 located at 411 Delaware St, Kansas City, MO 64105. Spacious 3600.0 Sq Ft store with regular business hours serving the Kansas City area. Contact: (816) 555-4567, rivermarket@com. Opened April 2020, managed by mgr_137. Convenient location in Kansas City, MO with excellent customer service and wide product selection.'),

-- Phoenix Area Stores
('070', 'Downtown Phoenix', '333 E Jefferson St', 'Phoenix', 'AZ', '85004', 'USA', '(602) 555-1234', 'dtphoenix@com', 'mgr_070', '2018-06-15', 4200.0, true, 33.4484, -112.074, '5', 'Downtown Phoenix store #070 located at 333 E Jefferson St, Phoenix, AZ 85004. Spacious 4200.0 Sq Ft store with open 24 hours serving the Phoenix area. Contact: (602) 555-1234, dtphoenix@com. Opened June 2018, managed by mgr_070. Convenient location in Phoenix, AZ with excellent customer service and wide product selection.'),
('071', 'Scottsdale', '7014 E Camelback Rd', 'Phoenix', 'AZ', '85251', 'USA', '(602) 555-2345', 'scottsdale@com', 'mgr_071', '2019-03-01', 3800.0, false, 33.4994, -111.9289, '5', 'Scottsdale store #071 located at 7014 E Camelback Rd, Phoenix, AZ 85251. Spacious 3800.0 Sq Ft store with regular business hours serving the Phoenix area. Contact: (602) 555-2345, scottsdale@com. Opened March 2019, managed by mgr_071. Convenient location in Phoenix, AZ with excellent customer service and wide product selection.'),
('072', 'Tempe', '2000 E Rio Salado Pkwy', 'Phoenix', 'AZ', '85281', 'USA', '(602) 555-3456', 'tempe@com', 'mgr_072', '2017-08-15', 4500.0, true, 33.4316, -111.9083, '5', 'Tempe store #072 located at 2000 E Rio Salado Pkwy, Phoenix, AZ 85281. Large 4500.0 Sq Ft store with open 24 hours serving the Phoenix area. Contact: (602) 555-3456, tempe@com. Opened August 2017, managed by mgr_072. Convenient location in Phoenix, AZ with excellent customer service and wide product selection.'),
('073', 'Glendale', '7700 W Arrowhead Towne Center', 'Phoenix', 'AZ', '85308', 'USA', '(602) 555-4567', 'glendale@com', 'mgr_073', '2020-01-10', 3200.0, false, 33.6377, -112.215, '5', 'Glendale store #073 located at 7700 W Arrowhead Towne Center, Phoenix, AZ 85308. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Phoenix area. Contact: (602) 555-4567, glendale@com. Opened January 2020, managed by mgr_073. Convenient location in Phoenix, AZ with excellent customer service and wide product selection.'),
('074', 'Mesa', '1230 S Val Vista Dr', 'Phoenix', 'AZ', '85204', 'USA', '(602) 555-5678', 'mesa@com', 'mgr_074', '2019-05-20', 3600.0, true, 33.3903, -111.7516, '5', 'Mesa store #074 located at 1230 S Val Vista Dr, Phoenix, AZ 85204. Spacious 3600.0 Sq Ft store with open 24 hours serving the Phoenix area. Contact: (602) 555-5678, mesa@com. Opened May 2019, managed by mgr_074. Convenient location in Phoenix, AZ with excellent customer service and wide product selection.'),

-- Las Vegas Area Stores
('075', 'Strip', '3500 Las Vegas Blvd S', 'Las Vegas', 'NV', '89109', 'USA', '(702) 555-1234', 'strip@com', 'mgr_075', '2018-12-01', 5000.0, true, 36.1147, -115.1728, '6', 'Strip store #075 located at 3500 Las Vegas Blvd S, Las Vegas, NV 89109. Large 5000.0 Sq Ft store with open 24 hours serving the Las Vegas area. Contact: (702) 555-1234, strip@com. Opened December 2018, managed by mgr_075. Convenient location in Las Vegas, NV with excellent customer service and wide product selection.'),
('076', 'Downtown Vegas', '301 Fremont St', 'Las Vegas', 'NV', '89101', 'USA', '(702) 555-2345', 'downtownvegas@com', 'mgr_076', '2017-07-15', 3800.0, true, 36.1699, -115.1398, '6', 'Downtown Vegas store #076 located at 301 Fremont St, Las Vegas, NV 89101. Spacious 3800.0 Sq Ft store with open 24 hours serving the Las Vegas area. Contact: (702) 555-2345, downtownvegas@com. Opened July 2017, managed by mgr_076. Convenient location in Las Vegas, NV with excellent customer service and wide product selection.'),
('077', 'Summerlin', '1980 Festival Plaza Dr', 'Las Vegas', 'NV', '89135', 'USA', '(702) 555-3456', 'summerlin@com', 'mgr_077', '2019-09-01', 4200.0, false, 36.1575, -115.3368, '6', 'Summerlin store #077 located at 1980 Festival Plaza Dr, Las Vegas, NV 89135. Spacious 4200.0 Sq Ft store with regular business hours serving the Las Vegas area. Contact: (702) 555-3456, summerlin@com. Opened September 2019, managed by mgr_077. Convenient location in Las Vegas, NV with excellent customer service and wide product selection.'),
('078', 'Henderson', '2300 Paseo Verde Pkwy', 'Las Vegas', 'NV', '89052', 'USA', '(702) 555-4567', 'henderson@com', 'mgr_078', '2020-02-15', 3500.0, false, 36.0145, -115.0874, '6', 'Henderson store #078 located at 2300 Paseo Verde Pkwy, Las Vegas, NV 89052. Spacious 3500.0 Sq Ft store with regular business hours serving the Las Vegas area. Contact: (702) 555-4567, henderson@com. Opened February 2020, managed by mgr_078. Convenient location in Las Vegas, NV with excellent customer service and wide product selection.'),
('079', 'Spring Valley', '4178 S Fort Apache Rd', 'Las Vegas', 'NV', '89147', 'USA', '(702) 555-5678', 'springvalley@com', 'mgr_079', '2018-04-01', 3300.0, true, 36.1087, -115.2977, '6', 'Spring Valley store #079 located at 4178 S Fort Apache Rd, Las Vegas, NV 89147. Mid-Size 3300.0 Sq Ft store with open 24 hours serving the Las Vegas area. Contact: (702) 555-5678, springvalley@com. Opened April 2018, managed by mgr_079. Convenient location in Las Vegas, NV with excellent customer service and wide product selection.'),

-- San Francisco Area Stores (Enhanced with more locations)
('080', 'Financial District', '343 Sansome St', 'San Francisco', 'CA', '94104', 'USA', '(415) 555-1234', 'fidi@com', 'mgr_080', '2017-06-01', 3200.0, false, 37.7936, -122.4014, '6', 'Financial District store #080 located at 343 Sansome St, San Francisco, CA 94104. Mid-Size 3200.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-1234, fidi@com. Opened June 2017, managed by mgr_080. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('081', 'Mission District', '2558 Mission St', 'San Francisco', 'CA', '94110', 'USA', '(415) 555-2345', 'mission@com', 'mgr_081', '2019-08-15', 2800.0, true, 37.7562, -122.4186, '6', 'Mission District store #081 located at 2558 Mission St, San Francisco, CA 94110. Compact 2800.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-2345, mission@com. Opened August 2019, managed by mgr_081. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('082', 'Hayes Valley', '432 Octavia St', 'San Francisco', 'CA', '94102', 'USA', '(415) 555-3456', 'hayes@com', 'mgr_082', '2018-03-01', 2500.0, false, 37.7765, -122.4242, '6', 'Hayes Valley store #082 located at 432 Octavia St, San Francisco, CA 94102. Compact 2500.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-3456, hayes@com. Opened March 2018, managed by mgr_082. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('083', 'Marina', '2040 Chestnut St', 'San Francisco', 'CA', '94123', 'USA', '(415) 555-4567', 'marina@com', 'mgr_083', '2020-01-15', 3000.0, false, 37.8009, -122.4368, '6', 'Marina store #083 located at 2040 Chestnut St, San Francisco, CA 94123. Mid-Size 3000.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-4567, marina@com. Opened January 2020, managed by mgr_083. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('084', 'Sunset District', '1200 Irving St', 'San Francisco', 'CA', '94122', 'USA', '(415) 555-5678', 'sunset@com', 'mgr_084', '2017-11-01', 3400.0, true, 37.7642, -122.4682, '6', 'Sunset District store #084 located at 1200 Irving St, San Francisco, CA 94122. Mid-Size 3400.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-5678, sunset@com. Opened November 2017, managed by mgr_084. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('153', 'Castro', '2300 Market St', 'San Francisco', 'CA', '94114', 'USA', '(415) 555-6789', 'castro@com', 'mgr_153', '2019-04-15', 2900.0, false, 37.7609, -122.4350, '6', 'Castro store #153 located at 2300 Market St, San Francisco, CA 94114. Compact 2900.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-6789, castro@com. Opened April 2019, managed by mgr_153. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('154', 'Chinatown', '800 Grant Ave', 'San Francisco', 'CA', '94108', 'USA', '(415) 555-7890', 'chinatown@com', 'mgr_154', '2018-09-01', 2200.0, true, 37.7946, -122.4058, '6', 'Chinatown store #154 located at 800 Grant Ave, San Francisco, CA 94108. Cozy 2200.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-7890, chinatown@com. Opened September 2018, managed by mgr_154. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('155', 'North Beach', '1650 Stockton St', 'San Francisco', 'CA', '94133', 'USA', '(415) 555-8901', 'northbeach@com', 'mgr_155', '2017-12-15', 2600.0, false, 37.8024, -122.4089, '6', 'North Beach store #155 located at 1650 Stockton St, San Francisco, CA 94133. Compact 2600.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-8901, northbeach@com. Opened December 2017, managed by mgr_155. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('156', 'Nob Hill', '1200 California St', 'San Francisco', 'CA', '94109', 'USA', '(415) 555-9012', 'nobhill@com', 'mgr_156', '2020-03-01', 2800.0, false, 37.7919, -122.4147, '6', 'Nob Hill store #156 located at 1200 California St, San Francisco, CA 94109. Compact 2800.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-9012, nobhill@com. Opened March 2020, managed by mgr_156. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('157', 'SOMA', '350 Townsend St', 'San Francisco', 'CA', '94107', 'USA', '(415) 555-0123', 'soma@com', 'mgr_157', '2019-07-15', 3500.0, true, 37.7749, -122.3959, '6', 'SOMA store #157 located at 350 Townsend St, San Francisco, CA 94107. Spacious 3500.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-0123, soma@com. Opened July 2019, managed by mgr_157. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('158', 'Richmond District', '3800 Geary Blvd', 'San Francisco', 'CA', '94118', 'USA', '(415) 555-1357', 'richmond@com', 'mgr_158', '2018-05-20', 3100.0, false, 37.7816, -122.4635, '6', 'Richmond District store #158 located at 3800 Geary Blvd, San Francisco, CA 94118. Mid-Size 3100.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-1357, richmond@com. Opened May 2018, managed by mgr_158. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('159', 'Haight-Ashbury', '1700 Haight St', 'San Francisco', 'CA', '94117', 'USA', '(415) 555-2468', 'haight@com', 'mgr_159', '2019-11-01', 2700.0, true, 37.7693, -122.4489, '6', 'Haight-Ashbury store #159 located at 1700 Haight St, San Francisco, CA 94117. Compact 2700.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-2468, haight@com. Opened November 2019, managed by mgr_159. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('160', 'Potrero Hill', '1200 18th St', 'San Francisco', 'CA', '94107', 'USA', '(415) 555-3579', 'potrero@com', 'mgr_160', '2020-06-15', 2900.0, false, 37.7615, -122.3972, '6', 'Potrero Hill store #160 located at 1200 18th St, San Francisco, CA 94107. Compact 2900.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-3579, potrero@com. Opened June 2020, managed by mgr_160. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('161', 'Presidio Heights', '3200 Sacramento St', 'San Francisco', 'CA', '94115', 'USA', '(415) 555-4680', 'presidio@com', 'mgr_161', '2017-08-30', 3300.0, false, 37.7886, -122.4394, '6', 'Presidio Heights store #161 located at 3200 Sacramento St, San Francisco, CA 94115. Mid-Size 3300.0 Sq Ft store with regular business hours serving the San Francisco area. Contact: (415) 555-4680, presidio@com. Opened August 2017, managed by mgr_161. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),
('162', 'Fillmore', '1800 Fillmore St', 'San Francisco', 'CA', '94115', 'USA', '(415) 555-5791', 'fillmore@com', 'mgr_162', '2018-10-10', 2800.0, true, 37.7849, -122.4326, '6', 'Fillmore store #162 located at 1800 Fillmore St, San Francisco, CA 94115. Compact 2800.0 Sq Ft store with open 24 hours serving the San Francisco area. Contact: (415) 555-5791, fillmore@com. Opened October 2018, managed by mgr_162. Convenient location in San Francisco, CA with excellent customer service and wide product selection.'),

-- Seattle Area Stores
('085', 'Capitol Hill Seattle', '1525 Broadway', 'Seattle', 'WA', '98122', 'USA', '(206) 555-1234', 'caphill@com', 'mgr_085', '2018-07-01', 3100.0, true, 47.6147, -122.3207, '7', 'Capitol Hill Seattle store #085 located at 1525 Broadway, Seattle, WA 98122. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Seattle area. Contact: (206) 555-1234, caphill@com. Opened July 2018, managed by mgr_085. Convenient location in Seattle, WA with excellent customer service and wide product selection.'),
('086', 'Ballard', '5701 24th Ave NW', 'Seattle', 'WA', '98107', 'USA', '(206) 555-2345', 'ballard@com', 'mgr_086', '2019-04-15', 3600.0, false, 47.6705, -122.3828, '7', 'Ballard store #086 located at 5701 24th Ave NW, Seattle, WA 98107. Spacious 3600.0 Sq Ft store with regular business hours serving the Seattle area. Contact: (206) 555-2345, ballard@com. Opened April 2019, managed by mgr_086. Convenient location in Seattle, WA with excellent customer service and wide product selection.'),
('087', 'Queen Anne', '2121 Queen Anne Ave N', 'Seattle', 'WA', '98109', 'USA', '(206) 555-3456', 'queenanne@com', 'mgr_087', '2017-09-01', 2900.0, false, 47.6372, -122.3566, '7', 'Queen Anne store #087 located at 2121 Queen Anne Ave N, Seattle, WA 98109. Compact 2900.0 Sq Ft store with regular business hours serving the Seattle area. Contact: (206) 555-3456, queenanne@com. Opened September 2017, managed by mgr_087. Convenient location in Seattle, WA with excellent customer service and wide product selection.'),
('088', 'South Lake Union', '400 Fairview Ave N', 'Seattle', 'WA', '98109', 'USA', '(206) 555-4567', 'slu@com', 'mgr_088', '2020-03-01', 4000.0, true, 47.6221, -122.3331, '7', 'South Lake Union store #088 located at 400 Fairview Ave N, Seattle, WA 98109. Spacious 4000.0 Sq Ft store with open 24 hours serving the Seattle area. Contact: (206) 555-4567, slu@com. Opened March 2020, managed by mgr_088. Convenient location in Seattle, WA with excellent customer service and wide product selection.'),
('089', 'West Seattle', '4555 California Ave SW', 'Seattle', 'WA', '98116', 'USA', '(206) 555-5678', 'westseattle@com', 'mgr_089', '2018-11-15', 3300.0, false, 47.5613, -122.3872, '7', 'West Seattle store #089 located at 4555 California Ave SW, Seattle, WA 98116. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Seattle area. Contact: (206) 555-5678, westseattle@com. Opened November 2018, managed by mgr_089. Convenient location in Seattle, WA with excellent customer service and wide product selection.'),

-- Portland Area Stores
('090', 'Pearl District', '1231 NW Couch St', 'Portland', 'OR', '97209', 'USA', '(503) 555-1234', 'pearl@com', 'mgr_090', '2017-12-01', 3700.0, false, 45.5233, -122.6843, '7', 'Pearl District store #090 located at 1231 NW Couch St, Portland, OR 97209. Spacious 3700.0 Sq Ft store with regular business hours serving the Portland area. Contact: (503) 555-1234, pearl@com. Opened December 2017, managed by mgr_090. Convenient location in Portland, OR with excellent customer service and wide product selection.'),
('091', 'Hawthorne', '3590 SE Hawthorne Blvd', 'Portland', 'OR', '97214', 'USA', '(503) 555-2345', 'hawthorne@com', 'mgr_091', '2019-06-15', 2800.0, true, 45.512, -122.6274, '7', 'Hawthorne store #091 located at 3590 SE Hawthorne Blvd, Portland, OR 97214. Compact 2800.0 Sq Ft store with open 24 hours serving the Portland area. Contact: (503) 555-2345, hawthorne@com. Opened June 2019, managed by mgr_091. Convenient location in Portland, OR with excellent customer service and wide product selection.'),
('092', 'Alberta Arts', '1504 NE Alberta St', 'Portland', 'OR', '97211', 'USA', '(503) 555-3456', 'alberta@com', 'mgr_092', '2018-08-01', 2600.0, false, 45.5589, -122.6499, '7', 'Alberta Arts store #092 located at 1504 NE Alberta St, Portland, OR 97211. Compact 2600.0 Sq Ft store with regular business hours serving the Portland area. Contact: (503) 555-3456, alberta@com. Opened August 2018, managed by mgr_092. Convenient location in Portland, OR with excellent customer service and wide product selection.'),
('093', 'Division Street', '3632 SE Division St', 'Portland', 'OR', '97202', 'USA', '(503) 555-4567', 'division@com', 'mgr_093', '2020-02-01', 3100.0, true, 45.505, -122.626, '7', 'Division Street store #093 located at 3632 SE Division St, Portland, OR 97202. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Portland area. Contact: (503) 555-4567, division@com. Opened February 2020, managed by mgr_093. Convenient location in Portland, OR with excellent customer service and wide product selection.'),
('094', 'Northwest District', '2375 NW Thurman St', 'Portland', 'OR', '97210', 'USA', '(503) 555-5678', 'nwdistrict@com', 'mgr_094', '2019-10-15', 3400.0, false, 45.5352, -122.6991, '7', 'Northwest District store #094 located at 2375 NW Thurman St, Portland, OR 97210. Mid-Size 3400.0 Sq Ft store with regular business hours serving the Portland area. Contact: (503) 555-5678, nwdistrict@com. Opened October 2019, managed by mgr_094. Convenient location in Portland, OR with excellent customer service and wide product selection.'),

-- Boise Area Stores
('095', 'Downtown Boise', '821 W Idaho St', 'Boise', 'ID', '83702', 'USA', '(208) 555-1234', 'dtboise@com', 'mgr_095', '2018-05-01', 3200.0, true, 43.6167, -116.2023, '7', 'Downtown Boise store #095 located at 821 W Idaho St, Boise, ID 83702. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Boise area. Contact: (208) 555-1234, dtboise@com. Opened May 2018, managed by mgr_095. Convenient location in Boise, ID with excellent customer service and wide product selection.'),
('100', 'North End', '1520 N 13th St', 'Boise', 'ID', '83702', 'USA', '(208) 555-6789', 'northend@com', 'mgr_100', '2019-06-15', 2800.0, false, 43.6289, -116.202, '7', 'North End store #100 located at 1520 N 13th St, Boise, ID 83702. Compact 2800.0 Sq Ft store with regular business hours serving the Boise area. Contact: (208) 555-6789, northend@com. Opened June 2019, managed by mgr_100. Convenient location in Boise, ID with excellent customer service and wide product selection.'),
('101', 'Boise Bench', '2520 Vista Ave', 'Boise', 'ID', '83705', 'USA', '(208) 555-7890', 'bench@com', 'mgr_101', '2017-09-01', 3100.0, true, 43.5923, -116.2157, '7', 'Boise Bench store #101 located at 2520 Vista Ave, Boise, ID 83705. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Boise area. Contact: (208) 555-7890, bench@com. Opened September 2017, managed by mgr_101. Convenient location in Boise, ID with excellent customer service and wide product selection.'),
('102', 'Hyde Park', '1501 N 13th St', 'Boise', 'ID', '83702', 'USA', '(208) 555-8901', 'hydepark@com', 'mgr_102', '2020-03-15', 2600.0, false, 43.6287, -116.2019, '7', 'Hyde Park store #102 located at 1501 N 13th St, Boise, ID 83702. Compact 2600.0 Sq Ft store with regular business hours serving the Boise area. Contact: (208) 555-8901, hydepark@com. Opened March 2020, managed by mgr_102. Convenient location in Boise, ID with excellent customer service and wide product selection.'),
('103', 'East End', '815 Warm Springs Ave', 'Boise', 'ID', '83712', 'USA', '(208) 555-9012', 'eastend@com', 'mgr_103', '2018-07-01', 2900.0, true, 43.6127, -116.1891, '7', 'East End store #103 located at 815 Warm Springs Ave, Boise, ID 83712. Compact 2900.0 Sq Ft store with open 24 hours serving the Boise area. Contact: (208) 555-9012, eastend@com. Opened July 2018, managed by mgr_103. Convenient location in Boise, ID with excellent customer service and wide product selection.'),

-- Salt Lake City Area Stores
('096', 'Sugar House', '2100 S 1100 E', 'Salt Lake City', 'UT', '84106', 'USA', '(801) 555-2345', 'sugarhouse@com', 'mgr_096', '2019-03-15', 3500.0, false, 40.7247, -111.8561, '8', 'Sugar House store #096 located at 2100 S 1100 E, Salt Lake City, UT 84106. Spacious 3500.0 Sq Ft store with regular business hours serving the Salt Lake City area. Contact: (801) 555-2345, sugarhouse@com. Opened March 2019, managed by mgr_096. Convenient location in Salt Lake City, UT with excellent customer service and wide product selection.'),
('104', 'Downtown SLC', '400 S State St', 'Salt Lake City', 'UT', '84111', 'USA', '(801) 555-3456', 'dtslc@com', 'mgr_104', '2017-11-01', 4200.0, true, 40.7608, -111.891, '8', 'Downtown SLC store #104 located at 400 S State St, Salt Lake City, UT 84111. Spacious 4200.0 Sq Ft store with open 24 hours serving the Salt Lake City area. Contact: (801) 555-3456, dtslc@com. Opened November 2017, managed by mgr_104. Convenient location in Salt Lake City, UT with excellent customer service and wide product selection.'),
('105', 'The Avenues', '402 E 3rd Ave', 'Salt Lake City', 'UT', '84103', 'USA', '(801) 555-4567', 'avenues@com', 'mgr_105', '2019-08-15', 2800.0, false, 40.7747, -111.8789, '8', 'The Avenues store #105 located at 402 E 3rd Ave, Salt Lake City, UT 84103. Compact 2800.0 Sq Ft store with regular business hours serving the Salt Lake City area. Contact: (801) 555-4567, avenues@com. Opened August 2019, managed by mgr_105. Convenient location in Salt Lake City, UT with excellent customer service and wide product selection.'),
('106', '9th and 9th', '900 E 900 S', 'Salt Lake City', 'UT', '84105', 'USA', '(801) 555-5678', 'ninth@com', 'mgr_106', '2018-04-01', 3100.0, true, 40.7508, -111.8646, '8', '9th and 9th store #106 located at 900 E 900 S, Salt Lake City, UT 84105. Mid-Size 3100.0 Sq Ft store with open 24 hours serving the Salt Lake City area. Contact: (801) 555-5678, ninth@com. Opened April 2018, managed by mgr_106. Convenient location in Salt Lake City, UT with excellent customer service and wide product selection.'),
('107', 'Capitol Hill SLC', '350 N State St', 'Salt Lake City', 'UT', '84103', 'USA', '(801) 555-6789', 'capitol@com', 'mgr_107', '2020-02-01', 2900.0, false, 40.7774, -111.8882, '8', 'Capitol Hill SLC store #107 located at 350 N State St, Salt Lake City, UT 84103. Compact 2900.0 Sq Ft store with regular business hours serving the Salt Lake City area. Contact: (801) 555-6789, capitol@com. Opened February 2020, managed by mgr_107. Convenient location in Salt Lake City, UT with excellent customer service and wide product selection.'),

-- Denver Area Stores
('097', 'LoDo', '1701 Wynkoop St', 'Denver', 'CO', '80202', 'USA', '(303) 555-3456', 'lodo@com', 'mgr_097', '2017-08-01', 4000.0, true, 39.7534, -104.9994, '8', 'LoDo store #097 located at 1701 Wynkoop St, Denver, CO 80202. Spacious 4000.0 Sq Ft store with open 24 hours serving the Denver area. Contact: (303) 555-3456, lodo@com. Opened August 2017, managed by mgr_097. Convenient location in Denver, CO with excellent customer service and wide product selection.'),
('108', 'Highland', '2532 15th St', 'Denver', 'CO', '80211', 'USA', '(303) 555-7890', 'highland@com', 'mgr_108', '2019-05-15', 3200.0, false, 39.7575, -105.0109, '8', 'Highland store #108 located at 2532 15th St, Denver, CO 80211. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Denver area. Contact: (303) 555-7890, highland@com. Opened May 2019, managed by mgr_108. Convenient location in Denver, CO with excellent customer service and wide product selection.'),
('109', 'Cherry Creek', '2800 E 2nd Ave', 'Denver', 'CO', '80206', 'USA', '(303) 555-8901', 'cherrycreek@com', 'mgr_109', '2018-06-01', 3800.0, true, 39.7179, -104.9567, '8', 'Cherry Creek store #109 located at 2800 E 2nd Ave, Denver, CO 80206. Spacious 3800.0 Sq Ft store with open 24 hours serving the Denver area. Contact: (303) 555-8901, cherrycreek@com. Opened June 2018, managed by mgr_109. Convenient location in Denver, CO with excellent customer service and wide product selection.'),
('110', 'Capitol Hill Denver', '1200 Grant St', 'Denver', 'CO', '80203', 'USA', '(303) 555-9012', 'caphilldenver@com', 'mgr_110', '2020-04-01', 2700.0, false, 39.7349, -104.9841, '8', 'Capitol Hill Denver store #110 located at 1200 Grant St, Denver, CO 80203. Compact 2700.0 Sq Ft store with regular business hours serving the Denver area. Contact: (303) 555-9012, caphilldenver@com. Opened April 2020, managed by mgr_110. Convenient location in Denver, CO with excellent customer service and wide product selection.'),
('111', 'RiNo', '2601 Larimer St', 'Denver', 'CO', '80205', 'USA', '(303) 555-0123', 'rino@com', 'mgr_111', '2019-09-15', 3400.0, true, 39.7594, -104.9847, '8', 'RiNo store #111 located at 2601 Larimer St, Denver, CO 80205. Mid-Size 3400.0 Sq Ft store with open 24 hours serving the Denver area. Contact: (303) 555-0123, rino@com. Opened September 2019, managed by mgr_111. Convenient location in Denver, CO with excellent customer service and wide product selection.'),

-- Colorado Springs Area Stores
('098', 'Old Colorado City', '2501 W Colorado Ave', 'Colorado Springs', 'CO', '80904', 'USA', '(719) 555-4567', 'oldcolorado@com', 'mgr_098', '2020-01-15', 3300.0, false, 38.8461, -104.8594, '8', 'Old Colorado City store #098 located at 2501 W Colorado Ave, Colorado Springs, CO 80904. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Colorado Springs area. Contact: (719) 555-4567, oldcolorado@com. Opened January 2020, managed by mgr_098. Convenient location in Colorado Springs, CO with excellent customer service and wide product selection.'),
('112', 'Downtown Springs', '115 E Pikes Peak Ave', 'Colorado Springs', 'CO', '80903', 'USA', '(719) 555-1234', 'dtsprings@com', 'mgr_112', '2018-03-01', 3600.0, true, 38.8339, -104.8208, '8', 'Downtown Springs store #112 located at 115 E Pikes Peak Ave, Colorado Springs, CO 80903. Spacious 3600.0 Sq Ft store with open 24 hours serving the Colorado Springs area. Contact: (719) 555-1234, dtsprings@com. Opened March 2018, managed by mgr_112. Convenient location in Colorado Springs, CO with excellent customer service and wide product selection.'),
('113', 'Broadmoor', '1 Lake Ave', 'Colorado Springs', 'CO', '80906', 'USA', '(719) 555-2345', 'broadmoor@com', 'mgr_113', '2019-07-15', 4100.0, false, 38.7897, -104.848, '8', 'Broadmoor store #113 located at 1 Lake Ave, Colorado Springs, CO 80906. Spacious 4100.0 Sq Ft store with regular business hours serving the Colorado Springs area. Contact: (719) 555-2345, broadmoor@com. Opened July 2019, managed by mgr_113. Convenient location in Colorado Springs, CO with excellent customer service and wide product selection.'),
('114', 'North Springs', '7915 N Academy Blvd', 'Colorado Springs', 'CO', '80920', 'USA', '(719) 555-3456', 'nsprings@com', 'mgr_114', '2017-12-01', 3200.0, true, 38.9327, -104.797, '8', 'North Springs store #114 located at 7915 N Academy Blvd, Colorado Springs, CO 80920. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Colorado Springs area. Contact: (719) 555-3456, nsprings@com. Opened December 2017, managed by mgr_114. Convenient location in Colorado Springs, CO with excellent customer service and wide product selection.'),
('115', 'Powers Center', '5640 Powers Center Point', 'Colorado Springs', 'CO', '80920', 'USA', '(719) 555-4567', 'powers@com', 'mgr_115', '2019-11-15', 3500.0, false, 38.9018, -104.7474, '8', 'Powers Center store #115 located at 5640 Powers Center Point, Colorado Springs, CO 80920. Spacious 3500.0 Sq Ft store with regular business hours serving the Colorado Springs area. Contact: (719) 555-4567, powers@com. Opened November 2019, managed by mgr_115. Convenient location in Colorado Springs, CO with excellent customer service and wide product selection.'),

-- Omaha Area Stores
('099', 'Old Market', '1022 Howard St', 'Omaha', 'NE', '68102', 'USA', '(402) 555-5678', 'oldmarket@com', 'mgr_099', '2018-11-01', 3600.0, true, 41.2565, -95.9345, '9', 'Old Market store #099 located at 1022 Howard St, Omaha, NE 68102. Spacious 3600.0 Sq Ft store with open 24 hours serving the Omaha area. Contact: (402) 555-5678, oldmarket@com. Opened November 2018, managed by mgr_099. Convenient location in Omaha, NE with excellent customer service and wide product selection.'),
('116', 'Dundee', '5001 Underwood Ave', 'Omaha', 'NE', '68132', 'USA', '(402) 555-6789', 'dundee@com', 'mgr_116', '2019-04-15', 2800.0, false, 41.2649, -95.9908, '9', 'Dundee store #116 located at 5001 Underwood Ave, Omaha, NE 68132. Compact 2800.0 Sq Ft store with regular business hours serving the Omaha area. Contact: (402) 555-6789, dundee@com. Opened April 2019, managed by mgr_116. Convenient location in Omaha, NE with excellent customer service and wide product selection.'),
('117', 'Benson', '6051 Maple St', 'Omaha', 'NE', '68104', 'USA', '(402) 555-7890', 'benson@com', 'mgr_117', '2017-07-01', 3200.0, true, 41.2841, -95.9977, '9', 'Benson store #117 located at 6051 Maple St, Omaha, NE 68104. Mid-Size 3200.0 Sq Ft store with open 24 hours serving the Omaha area. Contact: (402) 555-7890, benson@com. Opened July 2017, managed by mgr_117. Convenient location in Omaha, NE with excellent customer service and wide product selection.'),
('118', 'Aksarben', '2200 S 67th St', 'Omaha', 'NE', '68106', 'USA', '(402) 555-8901', 'aksarben@com', 'mgr_118', '2020-05-01', 3400.0, false, 41.2419, -96.0197, '9', 'Aksarben store #118 located at 2200 S 67th St, Omaha, NE 68106. Mid-Size 3400.0 Sq Ft store with regular business hours serving the Omaha area. Contact: (402) 555-8901, aksarben@com. Opened May 2020, managed by mgr_118. Convenient location in Omaha, NE with excellent customer service and wide product selection.'),

-- Wichita Area Stores
('129', 'Old Town Wichita', '300 N Mead St', 'Wichita', 'KS', '67202', 'USA', '(316) 555-1234', 'oldtown@com', 'mgr_129', '2019-04-01', 3100.0, false, 37.6897, -97.3375, '9', 'Old Town Wichita store #129 located at 300 N Mead St, Wichita, KS 67202. Mid-Size 3100.0 Sq Ft store with regular business hours serving the Wichita area. Contact: (316) 555-1234, oldtown@com. Opened April 2019, managed by mgr_129. Convenient location in Wichita, KS with excellent customer service and wide product selection.'),
('130', 'College Hill', '3302 E Douglas Ave', 'Wichita', 'KS', '67208', 'USA', '(316) 555-2345', 'collegehill@com', 'mgr_130', '2018-08-15', 2800.0, true, 37.6868, -97.2951, '9', 'College Hill store #130 located at 3302 E Douglas Ave, Wichita, KS 67208. Compact 2800.0 Sq Ft store with open 24 hours serving the Wichita area. Contact: (316) 555-2345, collegehill@com. Opened August 2018, managed by mgr_130. Convenient location in Wichita, KS with excellent customer service and wide product selection.'),
('131', 'Delano', '555 W Douglas Ave', 'Wichita', 'KS', '67213', 'USA', '(316) 555-3456', 'delano@com', 'mgr_131', '2017-12-01', 3300.0, false, 37.6868, -97.3475, '9', 'Delano store #131 located at 555 W Douglas Ave, Wichita, KS 67213. Mid-Size 3300.0 Sq Ft store with regular business hours serving the Wichita area. Contact: (316) 555-3456, delano@com. Opened December 2017, managed by mgr_131. Convenient location in Wichita, KS with excellent customer service and wide product selection.'),
('132', 'East Central', '2721 E Central Ave', 'Wichita', 'KS', '67214', 'USA', '(316) 555-4567', 'eastcentral@com', 'mgr_132', '2020-01-15', 2900.0, true, 37.6868, -97.3097, '9', 'East Central store #132 located at 2721 E Central Ave, Wichita, KS 67214. Compact 2900.0 Sq Ft store with open 24 hours serving the Wichita area. Contact: (316) 555-4567, eastcentral@com. Opened January 2020, managed by mgr_132. Convenient location in Wichita, KS with excellent customer service and wide product selection.'),
('133', 'Riverside', '924 W Central Ave', 'Wichita', 'KS', '67203', 'USA', '(316) 555-5678', 'riverside@com', 'mgr_133', '2019-07-01', 3500.0, false, 37.6868, -97.3597, '9', 'Riverside store #133 located at 924 W Central Ave, Wichita, KS 67203. Spacious 3500.0 Sq Ft store with regular business hours serving the Wichita area. Contact: (316) 555-5678, riverside@com. Opened July 2019, managed by mgr_133. Convenient location in Wichita, KS with excellent customer service and wide product selection.'),

-- Hawaii Stores
('119', 'Waikiki Beach', '2255 Kalakaua Ave', 'Honolulu', 'HI', '96815', 'USA', '(808) 555-1234', 'waikiki@com', 'mgr_119', '2019-10-15', 3000.0, true, 21.2793, -157.8283, '10', 'Waikiki Beach store #119 located at 2255 Kalakaua Ave, Honolulu, HI 96815. Mid-Size 3000.0 Sq Ft store with open 24 hours serving the Honolulu area. Contact: (808) 555-1234, waikiki@com. Opened October 2019, managed by mgr_119. Convenient location in Honolulu, HI with excellent customer service and wide product selection.'),
('120', 'Ala Moana', '1450 Ala Moana Blvd', 'Honolulu', 'HI', '96814', 'USA', '(808) 555-2345', 'alamoana@com', 'mgr_120', '2018-06-01', 4200.0, false, 21.2906, -157.843, '10', 'Ala Moana store #120 located at 1450 Ala Moana Blvd, Honolulu, HI 96814. Spacious 4200.0 Sq Ft store with regular business hours serving the Honolulu area. Contact: (808) 555-2345, alamoana@com. Opened June 2018, managed by mgr_120. Convenient location in Honolulu, HI with excellent customer service and wide product selection.'),
('121', 'Kapahulu', '725 Kapahulu Ave', 'Honolulu', 'HI', '96816', 'USA', '(808) 555-3456', 'kapahulu@com', 'mgr_121', '2019-03-15', 2800.0, false, 21.2843, -157.815, '10', 'Kapahulu store #121 located at 725 Kapahulu Ave, Honolulu, HI 96816. Compact 2800.0 Sq Ft store with regular business hours serving the Honolulu area. Contact: (808) 555-3456, kapahulu@com. Opened March 2019, managed by mgr_121. Convenient location in Honolulu, HI with excellent customer service and wide product selection.'),
('122', 'Kaimuki', '3618 Waialae Ave', 'Honolulu', 'HI', '96816', 'USA', '(808) 555-4567', 'kaimuki@com', 'mgr_122', '2017-11-01', 3100.0, false, 21.2824, -157.7989, '10', 'Kaimuki store #122 located at 3618 Waialae Ave, Honolulu, HI 96816. Mid-Size 3100.0 Sq Ft store with regular business hours serving the Honolulu area. Contact: (808) 555-4567, kaimuki@com. Opened November 2017, managed by mgr_122. Convenient location in Honolulu, HI with excellent customer service and wide product selection.'),
('123', 'Manoa Valley', '2752 Woodlawn Dr', 'Honolulu', 'HI', '96822', 'USA', '(808) 555-5678', 'manoa@com', 'mgr_123', '2020-02-15', 2900.0, false, 21.3097, -157.8099, '10', 'Manoa Valley store #123 located at 2752 Woodlawn Dr, Honolulu, HI 96822. Compact 2900.0 Sq Ft store with regular business hours serving the Honolulu area. Contact: (808) 555-5678, manoa@com. Opened February 2020, managed by mgr_123. Convenient location in Honolulu, HI with excellent customer service and wide product selection.'),

-- Alaska Stores
('124', 'Downtown Anchorage', '320 W 5th Ave', 'Anchorage', 'AK', '99501', 'USA', '(907) 555-1234', 'downtownanchorage@com', 'mgr_124', '2018-07-01', 3800.0, true, 61.2176, -149.8951, '10', 'Downtown Anchorage store #124 located at 320 W 5th Ave, Anchorage, AK 99501. Spacious 3800.0 Sq Ft store with open 24 hours serving the Anchorage area. Contact: (907) 555-1234, downtownanchorage@com. Opened July 2018, managed by mgr_124. Convenient location in Anchorage, AK with excellent customer service and wide product selection.'),
('125', 'Midtown Anchorage', '1200 W Northern Lights Blvd', 'Anchorage', 'AK', '99503', 'USA', '(907) 555-2345', 'midtownanchorage@com', 'mgr_125', '2019-05-15', 4200.0, true, 61.195, -149.9002, '10', 'Midtown Anchorage store #125 located at 1200 W Northern Lights Blvd, Anchorage, AK 99503. Spacious 4200.0 Sq Ft store with open 24 hours serving the Anchorage area. Contact: (907) 555-2345, midtownanchorage@com. Opened May 2019, managed by mgr_125. Convenient location in Anchorage, AK with excellent customer service and wide product selection.'),
('126', 'South Anchorage', '11409 Business Blvd', 'Anchorage', 'AK', '99515', 'USA', '(907) 555-3456', 'southanc@com', 'mgr_126', '2017-09-01', 3600.0, false, 61.1181, -149.878, '10', 'South Anchorage store #126 located at 11409 Business Blvd, Anchorage, AK 99515. Spacious 3600.0 Sq Ft store with regular business hours serving the Anchorage area. Contact: (907) 555-3456, southanc@com. Opened September 2017, managed by mgr_126. Convenient location in Anchorage, AK with excellent customer service and wide product selection.'),
('127', 'Eagle River', '12001 Business Blvd', 'Anchorage', 'AK', '99577', 'USA', '(907) 555-4567', 'eagleriver@com', 'mgr_127', '2020-03-01', 3200.0, false, 61.3293, -149.568, '10', 'Eagle River store #127 located at 12001 Business Blvd, Anchorage, AK 99577. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Anchorage area. Contact: (907) 555-4567, eagleriver@com. Opened March 2020, managed by mgr_127. Convenient location in Anchorage, AK with excellent customer service and wide product selection.'),
('128', 'Spenard', '1000 W Northern Lights Blvd', 'Anchorage', 'AK', '99503', 'USA', '(907) 555-5678', 'spenard@com', 'mgr_128', '2018-11-15', 3400.0, true, 61.195, -149.9002, '10', 'Spenard store #128 located at 1000 W Northern Lights Blvd, Anchorage, AK 99503. Mid-Size 3400.0 Sq Ft store with open 24 hours serving the Anchorage area. Contact: (907) 555-5678, spenard@com. Opened November 2018, managed by mgr_128. Convenient location in Anchorage, AK with excellent customer service and wide product selection.'),

-- Los Angeles Area Stores
('138', 'Downtown LA', '350 S Grand Ave', 'Los Angeles', 'CA', '90071', 'USA', '(213) 555-1234', 'dtla@com', 'mgr_138', '2018-06-15', 4200.0, true, 34.0522, -118.2437, '6', 'Downtown LA store #138 located at 350 S Grand Ave, Los Angeles, CA 90071. Spacious 4200.0 Sq Ft store with open 24 hours serving the Los Angeles area. Contact: (213) 555-1234, dtla@com. Opened June 2018, managed by mgr_138. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('139', 'Hollywood', '6380 Hollywood Blvd', 'Los Angeles', 'CA', '90028', 'USA', '(323) 555-2345', 'hollywood@com', 'mgr_139', '2019-03-01', 3500.0, true, 34.1016, -118.3267, '6', 'Hollywood store #139 located at 6380 Hollywood Blvd, Los Angeles, CA 90028. Spacious 3500.0 Sq Ft store with open 24 hours serving the Los Angeles area. Contact: (323) 555-2345, hollywood@com. Opened March 2019, managed by mgr_139. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('140', 'Venice Beach', '1800 Ocean Front Walk', 'Los Angeles', 'CA', '90291', 'USA', '(310) 555-3456', 'venice@com', 'mgr_140', '2017-08-01', 2800.0, false, 33.985, -118.4695, '6', 'Venice Beach store #140 located at 1800 Ocean Front Walk, Los Angeles, CA 90291. Compact 2800.0 Sq Ft store with regular business hours serving the Los Angeles area. Contact: (310) 555-3456, venice@com. Opened August 2017, managed by mgr_140. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('141', 'Silver Lake', '2800 Sunset Blvd', 'Los Angeles', 'CA', '90026', 'USA', '(323) 555-4567', 'silverlake@com', 'mgr_141', '2020-02-15', 3200.0, false, 34.0775, -118.2695, '6', 'Silver Lake store #141 located at 2800 Sunset Blvd, Los Angeles, CA 90026. Mid-Size 3200.0 Sq Ft store with regular business hours serving the Los Angeles area. Contact: (323) 555-4567, silverlake@com. Opened February 2020, managed by mgr_141. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('142', 'Echo Park', '1500 Echo Park Ave', 'Los Angeles', 'CA', '90026', 'USA', '(323) 555-5678', 'echopark@com', 'mgr_142', '2019-07-01', 2900.0, true, 34.0782, -118.2606, '6', 'Echo Park store #142 located at 1500 Echo Park Ave, Los Angeles, CA 90026. Compact 2900.0 sq ft store open 24 hours serving the Los Angeles area. Contact: (323) 555-5678, echopark@com. Opened July 2019, managed by mgr_142. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('143', 'Los Feliz', '1800 N Vermont Ave', 'Los Angeles', 'CA', '90027', 'USA', '(323) 555-6789', 'losfeliz@com', 'mgr_143', '2018-09-15', 3400.0, false, 34.1044, -118.2919, '6', 'Los Feliz store #143 located at 1800 N Vermont Ave, Los Angeles, CA 90027. Mid-size 3400.0 sq ft store with regular business hours serving the Los Angeles area. Contact: (323) 555-6789, losfeliz@com. Opened September 2018, managed by mgr_143. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('144', 'Koreatown', '3500 W 6th St', 'Los Angeles', 'CA', '90020', 'USA', '(213) 555-7890', 'ktown@com', 'mgr_144', '2017-11-01', 3800.0, true, 34.0628, -118.3002, '6', 'Koreatown store #144 located at 3500 W 6th St, Los Angeles, CA 90020. Spacious 3800.0 sq ft store open 24 hours serving the Los Angeles area. Contact: (213) 555-7890, ktown@com. Opened November 2017, managed by mgr_144. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('145', 'West LA', '11666 Olympic Blvd', 'Los Angeles', 'CA', '90064', 'USA', '(310) 555-8901', 'westla@com', 'mgr_145', '2020-01-15', 4000.0, false, 34.0379, -118.442, '6', 'West LA store #145 located at 11666 Olympic Blvd, Los Angeles, CA 90064. Large 4000.0 sq ft store with regular business hours serving the Los Angeles area. Contact: (310) 555-8901, westla@com. Opened January 2020, managed by mgr_145. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('146', 'Studio City', '12345 Ventura Blvd', 'Los Angeles', 'CA', '91604', 'USA', '(818) 555-9012', 'studiocity@com', 'mgr_146', '2019-05-01', 3600.0, true, 34.1395, -118.3968, '6', 'Studio City store #146 located at 12345 Ventura Blvd, Los Angeles, CA 91604. Spacious 3600.0 sq ft store open 24 hours serving the Los Angeles area. Contact: (818) 555-9012, studiocity@com. Opened May 2019, managed by mgr_146. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),
('147', 'Culver City', '9800 Washington Blvd', 'Los Angeles', 'CA', '90232', 'USA', '(310) 555-0123', 'culvercity@com', 'mgr_147', '2018-04-15', 3300.0, false, 34.0211, -118.3965, '6', 'Culver City store #147 located at 9800 Washington Blvd, Los Angeles, CA 90232. Mid-size 3300.0 sq ft store with regular business hours serving the Los Angeles area. Contact: (310) 555-0123, culvercity@com. Opened April 2018, managed by mgr_147. Convenient location in Los Angeles, CA with excellent customer service and wide product selection.'),

-- San Diego Area Stores
('148', 'Gaslamp Quarter', '614 5th Ave', 'San Diego', 'CA', '92101', 'USA', '(619) 555-1234', 'gaslamp@com', 'mgr_148', '2019-08-01', 3500.0, true, 32.7157, -117.1611, '6', 'Gaslamp Quarter store #148 located at 614 5th Ave, San Diego, CA 92101. Spacious 3500.0 Sq Ft store with open 24 hours serving the San Diego area. Contact: (619) 555-1234, gaslamp@com. Opened August 2019, managed by mgr_148. Convenient location in San Diego, CA with excellent customer service and wide product selection.'),
('149', 'Pacific Beach', '4516 Mission Blvd', 'San Diego', 'CA', '92109', 'USA', '(619) 555-2345', 'pacificbeach@com', 'mgr_149', '2018-07-15', 3200.0, false, 32.7972, -117.2546, '6', 'Pacific Beach store #149 located at 4516 Mission Blvd, San Diego, CA 92109. Mid-Size 3200.0 Sq Ft store with regular business hours serving the San Diego area. Contact: (619) 555-2345, pacificbeach@com. Opened July 2018, managed by mgr_149. Convenient location in San Diego, CA with excellent customer service and wide product selection.'),
('150', 'La Jolla', '7514 Girard Ave', 'San Diego', 'CA', '92037', 'USA', '(858) 555-3456', 'lajolla@com', 'mgr_150', '2017-12-01', 3800.0, true, 32.8473, -117.2742, '6', 'La Jolla store #150 located at 7514 Girard Ave, San Diego, CA 92037. Spacious 3800.0 Sq Ft store with open 24 hours serving the San Diego area. Contact: (858) 555-3456, lajolla@com. Opened December 2017, managed by mgr_150. Convenient location in San Diego, CA with excellent customer service and wide product selection.'),
('151', 'North Park', '3000 University Ave', 'San Diego', 'CA', '92104', 'USA', '(619) 555-4567', 'northpark@com', 'mgr_151', '2020-03-15', 2900.0, false, 32.7483, -117.1295, '6', 'North Park store #151 located at 3000 University Ave, San Diego, CA 92104. Compact 2900.0 Sq Ft store with regular business hours serving the San Diego area. Contact: (619) 555-4567, northpark@com. Opened March 2020, managed by mgr_151. Convenient location in San Diego, CA with excellent customer service and wide product selection.'),
('152', 'Little Italy SD', '1735 India St', 'San Diego', 'CA', '92101', 'USA', '(619) 555-5678', 'littleitaly@com', 'mgr_152', '2019-06-01', 3400.0, true, 32.7223, -117.1687, '6', 'Little Italy SD store #152 located at 1735 India St, San Diego, CA 92101. Mid-size 3400.0 sq ft store open 24 hours serving the San Diego area. Contact: (619) 555-5678, littleitaly@com. Opened June 2019, managed by mgr_152. Convenient location in San Diego, CA with excellent customer service and wide product selection.'); 